
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.017.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Determine Belorussian official holidays and business days.",
  "dist_author" => [
    "Vladimir Varlamov <bes.internal\@gmail.com>"
  ],
  "dist_name" => "Date-Holidays-BY",
  "dist_version" => "1.2021.1",
  "license" => "perl",
  "module_name" => "Date::Holidays::BY",
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "Date::Easter" => 0,
    "Exporter" => 0,
    "List::Util" => 0,
    "Time::Piece" => 0,
    "base" => 0,
    "perl" => "5.008",
    "strict" => 0,
    "utf8" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "Test::Exception" => 0,
    "Test::More" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::Exception" => 0,
  "Test::More" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
